@extends('templates.top')

@section('content')
<div class="container">
    <div class="card">
        <div class="card-header"> {{ $title }} </div>
        <div class="card-body">
            <button class="btn btn-primary" onclick="add_role()"><i class="fa fa-plus"></i> Tambah Role</button>
            <table id="roleTable" class="table table-striped">
                <thead>
                        <td>#</td>
                        <td>Nama</td>
                        <td>Deskripsi</td>
                        <td>Dibuat pada</td>
                        <td>Aksi</td>
                </thead>
                <tbody>
                    @foreach($roles as $role)
                    <tr>
                        <td>{{ $no[$role->id] }}</td>
                        <td>{{ $role->display_name }}</td>
                        <td>{{ $role->description }}</td>
                        <td>{{ $role->created_at }}</td>
                        <td>
                            <a class="btn btn-primary" href="{{ url('roles/assign/' .$role->id) }}"><i class="fa fa-eye"></i> Lihat</a>
                            <button onclick="edit_role({{$role->id}})" class="btn btn-success"><i class="fa fa-pencil"></i> Edit</button>
                            <button onclick="delete_role({{$role->id}})" class="btn btn-danger"><i class="fa fa-remove"></i> Hapus</button>
                        </td>
                    </tr>
                    @endforeach
                </tbody>
            </table>
        </div>
    </div>
</div>

<!-- start modal content -->
<div id="modal_form" class="modal fade" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true" style="display: none;">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h4 class="modal-title"></h4>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
                </div>
                <div class="modal-body">
                    <div id="msg-container"></div> 
                    <form action="#" id="form" class="form-horizontal">
                        @csrf
                        <input type="hidden" value="" name="roleID">
                        <div class="form-body">
                            <div class="form-group">
                                <label for="rolename" class="control-label">Nama Role: <span class="text-danger">*</span></label>
                                <input name="rolename" type="text" class="form-control" id="rolename">
                            </div>
                            <div class="form-group">
                                    <label for="desc" class="control-label">Deskripsi: <span class="text-danger">*</span></label>
                                    <textarea class="form-control" name="desc" id="desc" cols="30" rows="10"></textarea>
                            </div>
                        </div>
                    </form>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-default waves-effect" data-dismiss="modal">Batal</button>
                    <button type="button" class="btn btn-danger waves-effect waves-light" id="btnSave" onclick="save()">Simpan</button>
                </div>
            </div>
        </div>
    </div>
    <!-- /.modal -->

<script>

    var save_method;
    var http_method;

    $(document).ready(function() {
        $('#roleTable').DataTable({
            "aaSorting"     : []
        });
    });

    function add_role()
    {
        save_method = 'add';
      $('#form')[0].reset(); // reset form on modals
      $('#modal_form').modal('show'); // show bootstrap modal
      $('.modal-title').text('Tambah role'); // Set Title to Bootstrap modal title
    }

    function edit_role(id)
    {
      save_method = 'update';
      $('#form')[0].reset(); // reset form on modals

      //Ajax Load data from ajax
      $.ajax({
        url : "<?php echo url('roles/edit/')?>/" + id,
        type: "GET",
        dataType: "JSON",
        success: function(data)
        {

            $('[name="roleID"]').val(data.id);
            $('[name="rolename"]').val(data.name);
            $('[name="desc"]').val(data.description);

            $('#modal_form').modal('show'); // show bootstrap modal when complete loaded
            $('.modal-title').text('Edit role'); // Set title to Bootstrap modal title

        },
        error: function (jqXHR, textStatus, errorThrown)
        {
            // alert('Error get data from ajax');
            swal("Error!", "Maaf terjadi kesalahan.", "warning"); 
        }
      });
    }

    function save()
    {
      var url;
      if(save_method == 'add')
      {
        url = "<?php echo url('roles/store')?>";
        http_method = "POST";
      }
      else
      {
          roleID = $('[name="roleID"]').val();
        url = "<?php echo url('roles/update')?>"+'/'+roleID;
        http_method = "PUT";
      }

      $('#modal_form').modal('hide');
      $('#loading').show();
      setTimeout(function() {
       // ajax adding data to database
        $.ajax({
            url : url,
            type: http_method,
            data: $('#form').serialize(),
            dataType: "JSON",
            success: function(data)
            {
              //if success close modal and reload ajax table
              
                if (data.st === 0) {
                  $('#msg-container').html("<div class='alert alert-danger'><button type='button' class='close' data-dismiss='alert' aria-label='Close'> <span aria-hidden='true'>×</span> </button><center><h3 class='text-danger'><i class='fa fa-exclamation-circle'></i> Danger</h3>"+data.msg+"</center></div>");
                  $('#modal_form').modal('show');
                  $('#loading').hide();
                } else {
                  $('#msg-container').html('');
                  $('#loading').hide();
                  swal("Success!", "Data berhasil disimpan!", "success");
 
                  setTimeout(function(){ 
                      location.reload(); 
                    }, 1000);
                }
            },
            error: function (jqXHR, textStatus, errorThrown)
            {
                // alert('Error adding / update data');
                swal({   
                    title: "Kesalahan",   
                    text: "Maaf, terjadi kesalahan saat proses!",   
                    type: "warning", 
                    showConfirmButton: true
                })
            }
        });

      },1500);
    }

    function delete_role(id)
    {
        swal({   
            title: "Anda yakin?",   
            text: "Anda tidak bisa mengembalikan data yang dihapus!",   
            type: "warning",   
            showCancelButton: true,   
            confirmButtonColor: "#DD6B55",   
            confirmButtonText: "Ya, hapus!",   
            cancelButtonText: "Batal",
            closeOnConfirm: false 
        }, function(){
            setTimeout(function() {
                $.ajax({
                    url : "<?php echo url('roles/delete')?>/"+id,
                    type: "DELETE",
                    data: $('#form').serialize(),
                    dataType: "JSON",
                    success: function(data)
                    {
                        if(data.status){
                            $('#modal_form').modal('hide');
                            swal("Deleted!", "Data telah dihapus!", "success");
                            setTimeout(function(){ 
                              location.reload(); 
                            }, 1000);
                        }else{
                            swal("Warning!", "Proses gagal!", "warning");
                        }
                    },
                    error: function (jqXHR, textStatus, errorThrown)
                    {
                        swal("Error!", "Maaf terjadi kesalahan.", "error"); 
                    }
                });
            },1100)
        });
    }
</script>
@endsection