@extends('templates.top')

@section('content')
    <div class="row">
        <div class="col-md-12">
            <a href="{{ url('forms') }}" style="margin-bottom: 20px;" class="btn btn-danger"><i class="fa fa-reply"></i> Kembali</a>
            <div class="card">
                <div class="card-header"><button class="btn btn-primary" onclick="add()"><i class="fa fa-plus"></i> Tambah</button></div>

                <div class="card-body">
                    @if ($errors->any())
                        <div class="alert alert-danger">
                            <ul>
                                @foreach ($errors->all() as $error)
                                    <li>{{ $error }}</li>
                                @endforeach
                            </ul>
                        </div>
                    @endif
                    
                    <table id="stockbalanceTable" class="table table-bordered table-striped">
                        <thead>
                            <tr>
                                <th>#</th>
                                <th>Tanggal</th>
                                <th>Waktu</th>
                                <th>Dibuat oleh</th>
                                <th>Aksi</th>
                            </tr>
                        </thead>

                        <tbody>
                            @foreach($stockbalances as $key => $val)
                            <tr>
                                <td>{{ $no[$val->id] }}</td>
                                <td> {{ date('l, d-m-Y', strtotime($val->used_date)) }} </td>
                                <td> {{ date('H : i', strtotime($val->created_at)) }} </td>
                                <td>{{ $val->username }}</td>
                                <td>
                                    <a class="btn btn-small btn-success" href="{{ URL::to('stockbalances/add/' . $val->id) }}">Lihat</a>
                                    <button onclick="stocktakingSync({{ $val->id }})" class="btn btn-warning"><i class="fa fa-refresh"></i> Sinkron SO</button>
                                </td>
                            </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>

    <script>

    $( document ).ready(function() {
        $('#stockbalanceTable').DataTable({
            "aaSorting"     : []
        });
    });

    function add() {
        swal({   
            title: "Anda akan membuat saldo awal hari ini",   
            text: "*Pastikan semua data dilengkapi\n*Anda bertanggung jawab atas data yang anda buat",   
            type: "warning",   
            showCancelButton: true,   
            confirmButtonColor: "#DD6B55",   
            confirmButtonText: "Ya, saya yakin!",   
            cancelButtonText: "Batal",
            closeOnConfirm: false 
        }, function(){
            setTimeout(function() {
                // ajax adding data to database
                $.ajax({
                    url : "<?php echo url('stockbalances/store')?>",
                    type: "POST",
                    headers: {
                        'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                    },
                    dataType: "JSON",
                    success: function(data)
                    {
                        swal(data.title, data.message, data.type, data.id);

                        if (data.type == 'success') {
                            setTimeout(function(){ 
                                reloadUrl = "<?php echo url('stockbalances/add')?>" +'/'+ data.id;
                                window.location = reloadUrl; 
                            }, 1500);   
                        }
                    },
                    error: function (jqXHR, textStatus, errorThrown)
                    {
                        // alert('Error adding / update data');
                        swal({   
                            title: "Kesalahan",   
                            text: "Maaf, terjadi kesalahan saat proses!",   
                            type: "warning", 
                            showConfirmButton: true
                        })
                    }
                });

            },1500);
        });
    }

    function show_add() {
        $('#form')[0].reset(); // reset form on modals
        $('#modal_form').modal('show'); // show bootstrap modal
        $('.modal-title').text('Tambah SO'); // Set Title to Bootstrap modal title
    }

    function stocktakingSync(id) {
        swal({   
            title: "Anda yakin?",   
            text: "Data akan di-sinkronkan dengan stok opname",   
            type: "warning",   
            showCancelButton: true,   
            confirmButtonColor: "#DD6B55",   
            confirmButtonText: "Ya, saya yakin!",   
            cancelButtonText: "Batal",
            closeOnConfirm: false 
        }, function(){
            setTimeout(function() {
                // ajax adding data to database
                $.ajax({
                    url : "<?php echo url('stockbalances/stocktakingsync')?>" +'/'+ id,
                    type: "POST",
                    headers: {
                        'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                    },
                    dataType: "JSON",
                    success: function(data)
                    {
                        swal(data.title, data.message, data.type);
                    },
                    error: function (jqXHR, textStatus, errorThrown)
                    {
                        // alert('Error adding / update data');
                        swal({   
                            title: "Kesalahan",   
                            text: "Maaf, terjadi kesalahan saat proses!",   
                            type: "warning", 
                            showConfirmButton: true
                        })
                    }
                });

            },1500);
        });
    }

    </script>
@endsection
