@extends('templates.top')

@section('content')
    <div class="row">
        <div class="col-md-12">
            <a href="{{ url('forms') }}" style="margin-bottom: 20px;" class="btn btn-danger"><i class="fa fa-reply"></i> Kembali</a>
            <div class="card">
                <div class="card-header"><button class="btn btn-primary" onclick="show_add()"><i class="fa fa-plus"></i> Tambah</button></div>

                <div class="card-body">
                    @if ($errors->any())
                        <div class="alert alert-danger">
                            <ul>
                                @foreach ($errors->all() as $error)
                                    <li>{{ $error }}</li>
                                @endforeach
                            </ul>
                        </div>
                    @endif
                    
                    <table id="stockoutTable" class="table table-bordered table-striped text-center">
                        <thead>
                            <tr>
                                <th>#</th>
                                <th>Tanggal</th>
                                <th>Waktu</th>
                                <th>Tujuan</th>
                                <th>Dibuat oleh</th>
                                <th>Aksi</th>
                            </tr>
                        </thead>

                        <tbody>
                            @foreach($stockouts as $key => $val)
                            <tr>
                                <td>{{ $no[$val->id] }}</td>
                                <td> {{ date('l, d-m-Y', strtotime($val->used_date)) }} </td>
                                <td> {{ date('H : i', strtotime($val->created_at)) }} </td>
                                <td>
                                    <span class="label label-warning">{{ $val->division->name }}</span>
                                </td>
                                <td>{{ $val->username }}</td>
                                <td>
                                    <a class="btn btn-small btn-success" href="{{ URL::to('stockouts/add/' . $val->id) }}">Lihat</a>
                                </td>
                            </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>

    <!-- start modal content -->
    <div id="modal_form" class="modal fade" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true" style="display: none;">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h4 class="modal-title"></h4>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
                </div>
                <div class="modal-body">
                    <div id="msg-container"></div> 
                    <form method="POST" action="{{ url('stockouts/store') }}" id="form" class="form-horizontal">
                        @csrf
                        <div class="form-body">
                            <div class="form-group">
                                <label for="division_id">Pilih Tujuan</label>
                                <select name="division_id" id="division_id" class="select2">
                                    @foreach($divisions as $division)
                                        <option value="{{ $division->id }}">{{ $division->name }}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-default waves-effect" data-dismiss="modal">Batal</button>
                        <button type="button" onclick="add()" class="btn btn-danger waves-effect waves-light" id="btnSave">Simpan</button>
                    </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
    <!-- /.modal -->

    <script>

    $( document ).ready(function() {
        $('#stockoutTable').DataTable({
            "aaSorting"     : []
        });
    });

    function show_add() {
        $('#form')[0].reset(); // reset form on modals
        $('#modal_form').modal('show'); // show bootstrap modal
        $('.modal-title').text('Tambah Keluar barang harian'); // Set Title to Bootstrap modal title
    }

    function add() {
        swal({   
            title: "Anda akan membuat keluar barang hari ini",   
            text: "*Pastikan semua data dilengkapi\n*Anda bertanggung jawab atas data yang anda buat",   
            type: "warning",   
            showCancelButton: true,   
            confirmButtonColor: "#DD6B55",   
            confirmButtonText: "Ya, saya yakin!",   
            cancelButtonText: "Batal",
            closeOnConfirm: false 
        }, function(){
            setTimeout(function() {
                // ajax adding data to database
                $.ajax({
                    url : "<?php echo url('stockouts/store')?>",
                    data: $('#form').serialize(),
                    type: "POST",
                    headers: {
                        'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                    },
                    dataType: "JSON",
                    success: function(data)
                    {
                        swal(data.title, data.message, data.type, data.id);

                        if (data.type == 'success') {
                            setTimeout(function(){ 
                                reloadUrl = "<?php echo url('stockouts/add')?>" +'/'+ data.id;
                                window.location = reloadUrl; 
                            }, 1500);   
                        }
                    },
                    error: function (jqXHR, textStatus, errorThrown)
                    {
                        // alert('Error adding / update data');
                        swal({   
                            title: "Kesalahan",   
                            text: "Maaf, terjadi kesalahan saat proses!",   
                            type: "warning", 
                            showConfirmButton: true
                        })
                    }
                });

            },1500);
        });
    }

    </script>
@endsection
