@extends('templates.top')

@section('content')
<div class="container">
    <div class="card">
        <div class="card-header"> {{ $title }} </div>
        <div class="card-body">
            <button class="btn btn-primary" onclick="add_user()"><i class="fa fa-plus"></i> Tambah Pengguna</button>
            <table id="userTable" class="table table-striped">
                <thead>
                        <td>#</td>
                        <td>Nama</td>
                        <td>Email</td>
                        <td>Dibuat pada</td>
                        <td>Aksi</td>
                </thead>
                <tbody>
                    @foreach($users as $user)
                    <tr>
                        <td>{{ $no[$user->id] }}</td>
                        <td>{{ $user->name }}</td>
                        <td>{{ $user->email }}</td>
                        <td>{{ $user->created_at }}</td>
                        <td>
                            <a href="{{ url('users/assign/' .$user->id) }}" class="btn btn-primary"><i class="fa fa-cogs"></i> Role</a>
                            <button onclick="edit_user({{$user->id}})" class="btn btn-success"><i class="fa fa-pencil"></i> Edit</button>
                            <button onclick="delete_user({{$user->id}})" class="btn btn-danger"><i class="fa fa-remove"></i> Hapus</button>
                        </td>
                    </tr>
                    @endforeach
                </tbody>
            </table>
        </div>
    </div>
</div>

<!-- start modal content -->
<div id="modal_form" class="modal fade" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true" style="display: none;">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h4 class="modal-title"></h4>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
                </div>
                <div class="modal-body">
                    <div id="msg-container"></div> 
                    <form action="#" id="form" class="form-horizontal" enctype="multipart/form-data">
                        @csrf
                        <input type="hidden" value="" name="userID">
                        {{ method_field('PUT') }}
                        <div class="form-body">
                            <div class="form-group">
                                <label for="username" class="control-label">Username: <span class="text-danger">*</span></label>
                                <input name="username" type="text" class="form-control" id="username">
                            </div>
                            <div class="form-group">
                                <label for="email" class="control-label">Email: <span class="text-danger">*</span></label>
                                <input name="email" type="text" class="form-control" id="email">
                            </div>
                            <div class="form-group">
                                <label for="image" class="control-label">Foto Profil: </label>
                                <input name="image" type="file" class="form-control-file" id="image">
                            </div>
                            <div class="form-group">
                                <label for="password" class="control-label">Password: <span class="text-danger">*</span></label>
                                <input name="password" type="password" class="form-control" id="password">
                            </div>
                            <div class="form-group">
                                <label for="password_confirmation" class="control-label">Konfirmasi Password: <span class="text-danger">*</span></label>
                                <input name="password_confirmation" type="password" class="form-control" id="password_confirmation">
                            </div>
                        </div>
                    </form>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-default waves-effect" data-dismiss="modal">Batal</button>
                    <button type="button" class="btn btn-danger waves-effect waves-light" id="btnSave" onclick="save()">Simpan</button>
                </div>
            </div>
        </div>
    </div>
    <!-- /.modal -->

<script>

    var save_method;
    var http_method;

    $(document).ready(function() {
        $('#userTable').DataTable({
            "aaSorting"     : []
        });
    });

    function add_user()
    {
        save_method = 'add';
        $('#form')[0].reset(); // reset form on modals
        $('#modal_form').modal('show'); // show bootstrap modal
        $('.modal-title').text('Tambah User'); // Set Title to Bootstrap modal title
    }

    function edit_user(id)
    {
      save_method = 'update';
      $('#form')[0].reset(); // reset form on modals

      //Ajax Load data from ajax
      $.ajax({
        url : "<?php echo url('users/edit/')?>/" + id,
        type: "GET",
        dataType: "JSON",
        success: function(data)
        {

            $('[name="userID"]').val(data.id);
            $('[name="username"]').val(data.name);
            $('[name="email"]').val(data.email);

            $('#modal_form').modal('show'); // show bootstrap modal when complete loaded
            $('.modal-title').text('Edit User'); // Set title to Bootstrap modal title

        },
        error: function (jqXHR, textStatus, errorThrown)
        {
            // alert('Error get data from ajax');
            swal("Error!", "Maaf terjadi kesalahan.", "warning"); 
        }
      });
    }

    function save()
    {
      var url;
      var formData = new FormData($('#form')[0]);
      //formData.append('_method', 'PATCH');
      
      if(save_method == 'add')
      {
        url = "<?php echo url('users/store')?>";
        http_method = "POST";
      }
      else
      {
        userID = $('[name="userID"]').val();
        url = "<?php echo url('users/update')?>"+'/'+userID;
        http_method = "POST";
      }

      $('#modal_form').modal('hide');
      $('#loading').show();
      setTimeout(function() {
       // ajax adding data to database
        $.ajax({
            url : url,
            type: http_method,
            headers: {
                'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
            },
            data: formData,
            dataType: "JSON",
            cache: false,
            processData: false,
            contentType: false,
            success: function(data)
            {
              //if success close modal and reload ajax table
              
                if (data.st === 0) {
                  $('#msg-container').html("<div class='alert alert-danger'><button type='button' class='close' data-dismiss='alert' aria-label='Close'> <span aria-hidden='true'>×</span> </button><center><h3 class='text-danger'><i class='fa fa-exclamation-circle'></i> Danger</h3>"+data.msg+"</center></div>");
                  $('#modal_form').modal('show');
                  $('#loading').hide();
                } else {
                  $('#msg-container').html('');
                  $('#loading').hide();
                  swal("Success!", "Data berhasil disimpan!", "success");
 
                  setTimeout(function(){ 
                      location.reload(); 
                    }, 1000);
                }
            },
            error: function (jqXHR, textStatus, errorThrown)
            {
                // alert('Error adding / update data');
                swal({   
                    title: "Kesalahan",   
                    text: "Maaf, terjadi kesalahan saat proses!",   
                    type: "warning", 
                    showConfirmButton: true
                })
            }
        });

      },1500);
    }

    function delete_user(id)
    {
        swal({   
            title: "Anda yakin?",   
            text: "Anda tidak bisa mengembalikan data yang dihapus!",   
            type: "warning",   
            showCancelButton: true,   
            confirmButtonColor: "#DD6B55",   
            confirmButtonText: "Ya, hapus!",   
            cancelButtonText: "Batal",
            closeOnConfirm: false 
        }, function(){
            setTimeout(function() {
                $.ajax({
                    url : "<?php echo url('users/delete')?>/"+id,
                    type: "DELETE",
                    data: $('#form').serialize(),
                    dataType: "JSON",
                    success: function(data)
                    {
                        if(data.status){
                            $('#modal_form').modal('hide');
                            swal("Deleted!", "Data telah dihapus!", "success");
                            setTimeout(function(){ 
                              location.reload(); 
                            }, 1000);
                        }else{
                            swal("Warning!", "Proses gagal!", "warning");
                        }
                    },
                    error: function (jqXHR, textStatus, errorThrown)
                    {
                        swal("Error!", "Maaf terjadi kesalahan.", "error"); 
                    }
                });
            },1100)
        });
    }
</script>
@endsection